#####################################
OdinWeb for `aiohttp` and Python 3.6+
#####################################

OdinWeb API framework for aiohttp. For building your APIs using asyncio.

.. note:: Currently in development, APIs can change.

Features:

- API Framework designed around OpenAPI

- Built in support for OpenAPI spec

- Built in support for CORS

- Handling of validation of all incoming parameters (via Odin)

- Handling of Serialisation and Deserialisation of data into common API
  content types including JSON, XML, and YAML.

- Easily extensible.

- Built in Authorisation and customisble Authentication.

- Fully type annotated with Python 3.6+ typing support.


Contributions
=============

Contributions are always welcome, however please ensure the following
guidelines are met to ensure your PR will be accepted.

- AIOdinWeb uses Git-Flow

- Check with Flake8, this must pass

- Ensure type annotations are fully applied.

- Ensure your contribution comes with fast test cases (for PyTest)

- Documentation is generated from code, ensure your contribution is
  documented.

Thanks!

- 
